==> knative-model-4.12.0-sources.jar: annotations/io/fabric8/knative/messaging/v1/SubscriptionSpecBuilder.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SubscriptionSpecBuilder extends SubscriptionSpecFluentImpl<SubscriptionSpecBuilder> implements VisitableBuilder<SubscriptionSpec,SubscriptionSpecBuilder> {

    SubscriptionSpecFluent<?> fluent;
    Boolean validationEnabled;

    public SubscriptionSpecBuilder() { 
        this(true);
    }


    public SubscriptionSpecBuilder(Boolean validationEnabled) { 
        this(new SubscriptionSpec(), validationEnabled);
    }


    public SubscriptionSpecBuilder(SubscriptionSpecFluent<?> fluent) { 
        this(fluent, true);
    }


    public SubscriptionSpecBuilder(SubscriptionSpecFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new SubscriptionSpec(), validationEnabled);
    }


    public SubscriptionSpecBuilder(SubscriptionSpecFluent<?> fluent,SubscriptionSpec instance) { 
        this(fluent, instance, true);
    }


    public SubscriptionSpecBuilder(SubscriptionSpecFluent<?> fluent,SubscriptionSpec instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withChannel(instance.getChannel()); 
        fluent.withDelivery(instance.getDelivery()); 
        fluent.withReply(instance.getReply()); 
        fluent.withSubscriber(instance.getSubscriber()); 
        this.validationEnabled = validationEnabled; 
    }


    public SubscriptionSpecBuilder(SubscriptionSpec instance) { 
        this(instance,true);
    }


    public SubscriptionSpecBuilder(SubscriptionSpec instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withChannel(instance.getChannel()); 
        this.withDelivery(instance.getDelivery()); 
        this.withReply(instance.getReply()); 
        this.withSubscriber(instance.getSubscriber()); 
        this.validationEnabled = validationEnabled; 
    }


    public SubscriptionSpec build() {
        SubscriptionSpec buildable = new SubscriptionSpec(fluent.getChannel(),fluent.getDelivery(),fluent.getReply(),fluent.getSubscriber());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SubscriptionSpecBuilder that = (SubscriptionSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.0.2-sources.jar: annotations/io/fabric8/knative/messaging/v1/SubscriptionSpecBuilder.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SubscriptionSpecBuilder extends SubscriptionSpecFluentImpl<SubscriptionSpecBuilder> implements VisitableBuilder<SubscriptionSpec,SubscriptionSpecBuilder> {

    SubscriptionSpecFluent<?> fluent;
    Boolean validationEnabled;

    public SubscriptionSpecBuilder() {
        this(true);
    }

    public SubscriptionSpecBuilder(Boolean validationEnabled) {
        this(new SubscriptionSpec(), validationEnabled);
    }

    public SubscriptionSpecBuilder(SubscriptionSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public SubscriptionSpecBuilder(SubscriptionSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new SubscriptionSpec(), validationEnabled);
    }

    public SubscriptionSpecBuilder(SubscriptionSpecFluent<?> fluent,SubscriptionSpec instance) {
        this(fluent, instance, true);
    }

    public SubscriptionSpecBuilder(SubscriptionSpecFluent<?> fluent,SubscriptionSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withChannel(instance.getChannel()); 
        fluent.withDelivery(instance.getDelivery()); 
        fluent.withReply(instance.getReply()); 
        fluent.withSubscriber(instance.getSubscriber()); 
        this.validationEnabled = validationEnabled; 
    }

    public SubscriptionSpecBuilder(SubscriptionSpec instance) {
        this(instance,true);
    }

    public SubscriptionSpecBuilder(SubscriptionSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withChannel(instance.getChannel()); 
        this.withDelivery(instance.getDelivery()); 
        this.withReply(instance.getReply()); 
        this.withSubscriber(instance.getSubscriber()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.messaging.v1.EditableSubscriptionSpec build() {
        EditableSubscriptionSpec buildable = new EditableSubscriptionSpec(fluent.getChannel(),fluent.getDelivery(),fluent.getReply(),fluent.getSubscriber());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SubscriptionSpecBuilder that = (SubscriptionSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
